@@ -1,4 +1,9 @@
+"""
+Metadata for the split request.
+"""
+
 import pandas as pd
+from cachetools import TTLCache, cached
 
 SPLIT_REQUEST_AT_SIZE_BYTES = 104857600  # 100 MB
 
@@ -95,41 +100,48 @@ NUMBER_OF_DATA_POINTS_PER_HOUR = {
     r".*": 1,
 }
 
-END_OF_TODAY = pd.Timestamp.utcnow().replace(
-    hour=0, minute=0, second=0, microsecond=0
-) + pd.Timedelta(days=1)
+DATE_RANGE_CACHE = TTLCache(maxsize=1, ttl=60)
 
 
+def get_end_of_today():
+    """Returns the end of the current day as a pandas timestamp."""
+    return pd.Timestamp.utcnow().replace(
+        hour=0, minute=0, second=0, microsecond=0
+    ) + pd.Timedelta(days=1)
+
+
+@cached(cache=DATE_RANGE_CACHE)
 def get_date_range():
     """Returns the date range for which data is available to use for the split request."""
+    end_of_today = get_end_of_today()
     return {
         r"IV\/BrentOil": (
             pd.to_datetime("2000-01-04 22:00:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"IV\/CarbonEmissionsEUA": (
             pd.to_datetime("2008-07-04 16:00:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"IV\/Coal": (
             pd.to_datetime("2008-12-08 23:00:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"IV\/NaturalGas": (
             pd.to_datetime("2000-01-04 22:00:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"MET\/forecast_.*": (
             pd.to_datetime("2019-11-26 13:00:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"MET\/.*": (
             pd.to_datetime("2013-09-01 00:00:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"NP\/BuyCurve": (
             pd.to_datetime("2013-12-31 23:00:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"NP\/FlowsAtSystemPrice": (
             pd.to_datetime("2015-12-31 23:00:00+00"),
@@ -137,47 +149,47 @@ def get_date_range():
         ),
         r"NP\/HydroReservoir.*": (
             pd.to_datetime("2017-01-01 00:00:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"NP\/IntradayTrades": (
             pd.to_datetime("2010-01-01 00:00:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"NP\/NetFlowsAtSystemPrice": (
             pd.to_datetime("2013-12-31 23:00:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"NP\/SellCurve": (
             pd.to_datetime("2013-12-31 23:00:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"NP\/VolumeAcceptedBlocksBuy": (
             pd.to_datetime("2013-12-31 23:00:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"NP\/VolumeAcceptedBlocksSell": (
             pd.to_datetime("2013-12-31 23:00:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"NP\/.*": (
             pd.to_datetime("2015-12-31 23:00:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"SN\/Consumption": (
             pd.to_datetime("2000-12-31 23:00:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"SN\/ConsumptionTotal": (
             pd.to_datetime("2022-04-25 12:46:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"SN\/FCRNPrice": (
             pd.to_datetime("2013-01-07 23:00:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"SN\/FCRNVolume": (
             pd.to_datetime("2013-01-07 23:00:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"SN\/FCRWVolume": (
             pd.to_datetime("2013-01-11 23:00:00+00"),
@@ -185,43 +197,43 @@ def get_date_range():
         ),
         r"SN\/FlowExport": (
             pd.to_datetime("2018-12-31 23:00:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"SN\/FlowImport": (
             pd.to_datetime("2018-12-31 23:00:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"SN\/FlowNet": (
             pd.to_datetime("2018-12-31 23:00:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"SN\/ProductionHydro": (
             pd.to_datetime("2022-04-25 12:46:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"SN\/ProductionNuclear": (
             pd.to_datetime("2022-04-25 12:46:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"SN\/ProductionThermal": (
             pd.to_datetime("2022-04-25 12:46:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"SN\/ProductionTotal": (
             pd.to_datetime("2022-04-25 12:46:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"SN\/ProductionUnspecifiedSource": (
             pd.to_datetime("2022-04-25 12:46:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"SN\/ProductionWind": (
             pd.to_datetime("2022-04-25 12:46:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"SN\/Production": (
             pd.to_datetime("2000-12-31 23:00:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
         r"SN\/WeeklyMTS.*Time": (
             pd.to_datetime("2007-01-01 00:00:00+00"),
@@ -233,6 +245,6 @@ def get_date_range():
         ),
         r".*": (
             pd.to_datetime("2010-01-01 00:00:00+00"),
-            END_OF_TODAY,
+            end_of_today,
         ),
     }
